@@ -70,7 +70,7 @@ Mixer_ALSA::Mixer_ALSA( Mixer* mixer, int device ) : Mixer_Backend(mixer,  devic
 
 Mixer_ALSA::~Mixer_ALSA()
 {
-	kDebug() << "Destruct " << this;
+//	kDebug() << "Destruct " << this;
    close();
 }
 
@@ -479,7 +479,7 @@ void Mixer_ALSA::deinitAlsaPolling()
 int
 Mixer_ALSA::close()
 {
-	kDebug() << "close " << this;
+//	kDebug() << "close " << this;
 
   int ret=0;
   m_isOpen = false;
@@ -782,7 +782,8 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
                    case Volume::REARSIDERIGHT: ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_SIDE_RIGHT  , &vol);     break;
                    default: kDebug() << "FATAL: Unknown channel type for capture << " << vc.chid << " ... please report this";  break;
               }
-              if ( ret != 0 ) kDebug() << "readVolumeFromHW(" << devnum << ") [get_capture_volume] failed, errno=" << ret;
+              if ( ret != 0 )
+            	  kDebug() << "readVolumeFromHW(" << devnum << ") [get_capture_volume] failed, errno=" << ret;
               else volumeCapture.setVolume( vc.chid, vol);
        }
     } // has capture volume
