@@ -25,9 +25,14 @@
 #include <kdialog.h>
 
 class KMixPrefWidget;
+
+class QBoxLayout;
 class QCheckBox;
 class QFrame;
+class QLabel;
 class QRadioButton;
+class QShowEvent;
+class QWidget;
 
 class 
 KMixPrefDlg : public KDialog
@@ -47,18 +52,30 @@ KMixPrefDlg : public KDialog
       void apply();
       void dockIntoPanelChange(int state);
 
+  protected:
+    void showEvent ( QShowEvent * event );
+
   private:
-   QFrame *m_generalTab;
-   KMixPrefWidget *m_mixPrefTab;
+    void addWidgetToLayout(QWidget* widget, QBoxLayout* layout, int spacingBefore, QString toopTipText);
+
+
+    QFrame *m_generalTab;
 
    QCheckBox *m_dockingChk;
    QCheckBox *m_volumeChk;
+   QLabel *dynamicControlsRestoreWarning;
    QCheckBox *m_showTicks;
    QCheckBox *m_showLabels;
+   QCheckBox* m_showOSD;
    QCheckBox *m_onLogin;
+   QCheckBox *allowAutostart;
+   QLabel *allowAutostartWarning;
    QCheckBox *m_beepOnVolumeChange;
+   QLabel *volumeFeedbackWarning;
    QRadioButton *_rbVertical;
    QRadioButton *_rbHorizontal;
+   QRadioButton *_rbTraypopupVertical;
+   QRadioButton *_rbTraypopupHorizontal;
 };
 
 #endif // KMIXPREFDLG_H
